/*
 * @(#)Configuration.java	1.00 11/21/00
 * Copyright (c) 2000 by Paul Regenhardt,  All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Paul Regenhardt ("Confidential Information"). You shall not 
 * disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Paul Regenhardt.
 */

import java.io.*;
import java.util.*;
import java.net.*;

/**
 * The configuration class is used to load configuration data
 * for programs.  The format is a simple key/value separated
 * by whitespace, the third column is not used by the program
 * can be notes to increase the readability.  Lines beginning 
 * with a # are comments.:
 * <pre>
 * #key			value			Comments
 * PasswordFile	password.dat	name of password file
 * LogFile			log.dat
 * MaxLogSize		5000			Max number of lines in the log file
 * </pre>
 * 
 * @author Paul Regenhardt
 * @version 1.0
 */


public class Configuration {

    /**
     * A Hashtable that holds the key/value pairs.
     */
    private Hashtable data = new Hashtable();

    /**
     * Passing in the key will return the resultant value.  
     * If no matching key is found null is returned.
     * 
     * @param key The first column in the file
     * @return The matching second column value
     */
    public String get(String key) 
    {
        String s = (String) data.get(key);
        if (s == null) error(key);
        return s;
    }

    /**
     * Passing in the first column value will return the second column value as
     * an integer.
     * 
     * @param key the first column value
     * @return the second column value as an int
     */
    public int getInt(String key) 
    {
        String s = (String) data.get(key);
        if (s == null) error(key);
        int i = (new Integer(s)).intValue();
        return i;
    }

    /**
     * diagnostic routine for debugging.  If the key isn't found it 
     * prints the key value to the system output.
     * 
     * @param s The key that was not located
     */
    private void error(String s)
    {   
        System.out.println("Configuration parameter not found for "+s);
    }
    
    /**
     * This is the constructor for applications and it takes a file name.
     * 
     * @param fName Name of the file to read as the configuration
     */
    public Configuration(String fName) {
        String line;
        try {
            FileInputStream in = new FileInputStream(fName);
            BufferedReader r = new BufferedReader(new InputStreamReader(in));
            while ((line = r.readLine()) != null) {
                if (line.charAt(0) != '#') {
                    
                    // Key Value
                    StringTokenizer st = new StringTokenizer(line);
                    String key = (String) st.nextToken();
                    String value = (String) st.nextToken();
                    data.put(key, value);
                }
            }
            r.close();
        } catch (Exception e) {}
    }

    /**
     * This constructor is used with applets to load
     * the config file from an HTTP server.
     * 
     * @param codebase The URL to the configuration file.
     */
    public Configuration(URL codebase) {
        String line;
        try {
            URL url = new URL(codebase.toString()+"/config.dat");
            DataInputStream r = new DataInputStream(url.openStream());
            while ((line = r.readLine()) != null) {
                if (line.charAt(0) != '#') { // Comments begin with #
                    // Key Value
                    StringTokenizer st = new StringTokenizer(line);
                    String key = (String) st.nextToken();
                    String value = (String) st.nextToken();
                    data.put(key, value);
                }
            }
            r.close();
        } catch (Exception e) {}
    }
}

